@@ -854,11 +854,12 @@ Ext.ux.RapidApp.DataStoreAppField = Ext.extend(Ext.ux.RapidApp.ClickActionField,
 	win_height: 450,
 	value: null,
 	preloadAppWindow: true,
-	displayCache: {},
 	queryResolveInterval: 50,
 	
 	initComponent: function() {
 		Ext.ux.RapidApp.DataStoreAppField.superclass.initComponent.call(this);
+    
+    this.displayCache = {};
 		
 		if(!this.valueField || !this.displayField || this.valueField == this.displayField) {
 			this.noDisplayLookups = true;
@@ -1203,6 +1204,16 @@ Ext.ux.RapidApp.DataStoreAppField = Ext.extend(Ext.ux.RapidApp.ClickActionField,
 					layout: 'fit',
 					cmpListeners: {
 						afterrender: function(){
+            
+              // If this is a grid, take over its rowdblclick event to
+              // make it call the select_fn function
+              if(this.hasListener('rowdblclick')) {
+                // Clear all existing rowdblclick events
+                this.events.rowdblclick = true;
+                this.on('rowdblclick',function(grid,rowIndex,e){
+                  select_fn(null);
+                },this);
+              }
 							
 							// Save references in the window and field:
 							win.app = this, field.appStore = this.store;
@@ -1337,8 +1348,7 @@ Ext.ux.RapidApp.DataStoreAppField = Ext.extend(Ext.ux.RapidApp.ClickActionField,
 							// any existing double-click open setting. TODO: do this properly
 							this.loadTargetObj = null;
 							
-						},
-						rowdblclick: function(){ select_fn(null); }
+						}
 					},
 					cmpConfig: cmpConfig,
 					update_cmpConfig: update_cmpConfig
